@@ -28,8 +28,8 @@ class IntrinsicCalibSession(CalibrationSession, ABC):
                 os.mkdir('CalibrationNumpyData')
             os.mkdir('CalibrationNumpyData/Intrinsic/')
         if not os.path.exists('CapturedNumpyData/Intrinsic/'):
-            if not os.path.exists('CalibrationNumpyData'):
-                os.mkdir('CalibrationNumpyData')
+            if not os.path.exists('CapturedNumpyData'):
+                os.mkdir('CapturedNumpyData')
             os.mkdir('CapturedNumpyData/Intrinsic/')
             
         for i in range(self.no):
